/* istanbul ignore file */
/* tslint:disable */
/* eslint-disable */
import type { AccountId } from "../models/AccountId";
import type { ApiKeyDataValues } from "../models/ApiKeyDataValues";
import type { ApiKeyDetails } from "../models/ApiKeyDetails";
import type { ApiKeyId } from "../models/ApiKeyId";
import type { ApiKeyType } from "../models/ApiKeyType";
import type { DeleteApiKeyBatch } from "../models/DeleteApiKeyBatch";
import { request as __request } from "../core/request";

export class ApiKeysService {
  /**
   * Creates a new public or secret API key for the account.
   * @param accountId
   * @param apiKeyType
   * @param requestBody
   * @returns ApiKeyDetails Success.
   * @throws ApiError
   */
  public static async createApiKey(
    accountId: AccountId,
    apiKeyType: ApiKeyType,
    requestBody: ApiKeyDataValues
  ): Promise<ApiKeyDetails> {
    const result = await __request({
      method: "POST",
      path: `/v1/accounts/${accountId}/security/api_keys/${apiKeyType}`,
      body: requestBody,
      mediaType: "application/json",
      errors: {
        401: `Unauthenticated.`,
        403: `Unauthorized.`
      }
    });
    return result.body;
  }

  /**
   * Update an API key for an account.
   * @param accountId
   * @param apiKeyId
   * @param requestBody
   * @returns void
   * @throws ApiError
   */
  public static async updateApiKey(
    accountId: AccountId,
    apiKeyId: ApiKeyId,
    requestBody: ApiKeyDataValues
  ): Promise<void> {
    const result = await __request({
      method: "PUT",
      path: `/v1/accounts/${accountId}/security/api_keys/${apiKeyId}`,
      body: requestBody,
      mediaType: "application/json",
      errors: {
        401: `Unauthenticated.`,
        403: `Unauthorized.`
      }
    });
    return result.body;
  }

  /**
   * Deletes an API key from an account.
   * @param accountId
   * @param apiKeyId
   * @returns void
   * @throws ApiError
   */
  public static async deleteApiKey(accountId: AccountId, apiKeyId: ApiKeyId): Promise<void> {
    const result = await __request({
      method: "DELETE",
      path: `/v1/accounts/${accountId}/security/api_keys/${apiKeyId}`,
      errors: {
        401: `Unauthenticated.`,
        403: `Unauthorized.`
      }
    });
    return result.body;
  }

  /**
   * Deletes multiple API keys from an account.
   * @param accountId
   * @param requestBody
   * @returns void
   * @throws ApiError
   */
  public static async deleteApiKeyBatch(accountId: AccountId, requestBody: DeleteApiKeyBatch): Promise<void> {
    const result = await __request({
      method: "DELETE",
      path: `/v1/accounts/${accountId}/security/api_keys`,
      body: requestBody,
      mediaType: "application/json",
      errors: {
        401: `Unauthenticated.`,
        403: `Unauthorized.`
      }
    });
    return result.body;
  }
}
